@@ -7,11 +7,17 @@
 # see:
 # - Module::Package
 
+# TODO
+# - Look at auto_provides
+# - Look at other plugins
+
 package Module::Package::Ingy;
 use strict;
 use 5.008003;
 use Module::Package 0.22 ();
 use Module::Install::AckXXX 0.16 ();
+use Module::Install::AutoLicense 0.08 ();
+use Module::Install::GithubMeta 0.10 ();
 use Module::Install::ReadmeFromPod 0.12 ();
 use Module::Install::Stardoc 0.13 ();
 use Module::Install::VersionCheck 0.14 ();
@@ -19,7 +25,7 @@ use IO::All 0.41;
 use YAML::XS 0.35 ();
 use Capture::Tiny 0.10 ();
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 #-----------------------------------------------------------------------------#
 package Module::Package::Ingy::modern;
@@ -42,17 +48,12 @@ sub main {
 
     # These run later, as specified.
     $self->post_all_from(sub {$self->mi->version_check});
-    $self->post_all_from(sub {$self->check_github_repository});
+    $self->post_all_from(sub {$self->mi->auto_license});
+    $self->post_all_from(sub {$self->mi->clean_files('LICENSE')});
+    $self->post_all_from(sub {$self->mi->githubmeta});
     $self->post_WriteAll(sub {$self->make_release});
 }
 
-sub check_github_repository {
-    my ($self) = @_;
-    -d '.git' or return;
-    `git remote -v` =~ /\bgit\@github.com:(\S+)/ or return;
-    $self->mi->repository("git://github.com/$1");
-}
-
 sub make_release {
     io('Makefile')->append(<<'...');
 
@@ -147,7 +148,7 @@ sub make_release {
 
 $meta->{name}-$meta->{version} successfully released.
 
-Relax. Have a beer.
+Relax. Have a beer. \\o/
 
 ...
 }
